@@ -306,6 +306,21 @@ void    cleanup_extracted_finish(CLEANUP_STATE *state)
 	&& state->recip != 0 && *var_always_bcc)
 	cleanup_addr_bcc(state, var_always_bcc);
 
+    /*
+     * Flush non-Milter header/body_checks BCC recipients. Clear hbc_rcpt
+     * so that it can be used for other purposes.
+     */
+    if (state->hbc_rcpt) {
+	if (CLEANUP_OUT_OK(state) && state->recip != 0) {
+	    char  **cpp;
+
+	    for (cpp = state->hbc_rcpt->argv; *cpp; cpp++)
+		cleanup_addr_bcc(state, *cpp);
+	}
+	argv_free(state->hbc_rcpt);
+	state->hbc_rcpt = 0;
+    }
+
     /*
      * Terminate the extracted segment.
      */
